##  Prerequisite: Build an Application Inventory in SAP LeanIX
Begin by building application inventory in SAP LeanIX, ensuring your workspace is equipped with essential data. Refer to the [Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD "Establish transparency and governance over your as-is landscape to identify optimization opportunities and unlock further use cases.") use case for a detailed step-by-step guide.
In a nutshell, you take the following steps:
  * Create your application inventory in SAP LeanIX
  * Create a business capability map.
  * Enrich your data and establish relevant relationships among various fact sheets.
